# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.display
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.foundation.numerics
import winsdk.windows.graphics
import winsdk.windows.graphics.directx
import winsdk.windows.graphics.directx.direct3d11
import winsdk.windows.storage.streams

class DisplayBitsPerChannel(enum.IntFlag):
    NONE = 0
    BPC6 = 0x1
    BPC8 = 0x2
    BPC10 = 0x4
    BPC12 = 0x8
    BPC14 = 0x10
    BPC16 = 0x20

class DisplayDeviceCapability(enum.IntEnum):
    FLIP_OVERRIDE = 0

class DisplayManagerOptions(enum.IntFlag):
    NONE = 0
    ENFORCE_SOURCE_OWNERSHIP = 0x1
    VIRTUAL_REFRESH_RATE_AWARE = 0x2

class DisplayManagerResult(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    TARGET_ACCESS_DENIED = 2
    TARGET_STALE = 3
    REMOTE_SESSION_NOT_SUPPORTED = 4

class DisplayModeQueryOptions(enum.IntFlag):
    NONE = 0
    ONLY_PREFERRED_RESOLUTION = 0x1

class DisplayPathScaling(enum.IntEnum):
    IDENTITY = 0
    CENTERED = 1
    STRETCHED = 2
    ASPECT_RATIO_STRETCHED = 3
    CUSTOM = 4
    DRIVER_PREFERRED = 5

class DisplayPathStatus(enum.IntEnum):
    UNKNOWN = 0
    SUCCEEDED = 1
    PENDING = 2
    FAILED = 3
    FAILED_ASYNC = 4
    INVALIDATED_ASYNC = 5

class DisplayPresentStatus(enum.IntEnum):
    SUCCESS = 0
    SOURCE_STATUS_PREVENTED_PRESENT = 1
    SCANOUT_INVALID = 2
    SOURCE_INVALID = 3
    DEVICE_INVALID = 4
    UNKNOWN_FAILURE = 5

class DisplayRotation(enum.IntEnum):
    NONE = 0
    CLOCKWISE90_DEGREES = 1
    CLOCKWISE180_DEGREES = 2
    CLOCKWISE270_DEGREES = 3

class DisplayScanoutOptions(enum.IntFlag):
    NONE = 0
    ALLOW_TEARING = 0x2

class DisplaySourceStatus(enum.IntEnum):
    ACTIVE = 0
    POWERED_OFF = 1
    INVALID = 2
    OWNED_BY_ANOTHER_DEVICE = 3
    UNOWNED = 4

class DisplayStateApplyOptions(enum.IntFlag):
    NONE = 0
    FAIL_IF_STATE_CHANGED = 0x1
    FORCE_REAPPLY = 0x2
    FORCE_MODE_ENUMERATION = 0x4

class DisplayStateFunctionalizeOptions(enum.IntFlag):
    NONE = 0
    FAIL_IF_STATE_CHANGED = 0x1
    VALIDATE_TOPOLOGY_ONLY = 0x2

class DisplayStateOperationStatus(enum.IntEnum):
    SUCCESS = 0
    PARTIAL_FAILURE = 1
    UNKNOWN_FAILURE = 2
    TARGET_OWNERSHIP_LOST = 3
    SYSTEM_STATE_CHANGED = 4
    TOO_MANY_PATHS_FOR_ADAPTER = 5
    MODES_NOT_SUPPORTED = 6
    REMOTE_SESSION_NOT_SUPPORTED = 7

class DisplayTargetPersistence(enum.IntEnum):
    NONE = 0
    BOOT_PERSISTED = 1
    TEMPORARY_PERSISTED = 2
    PATH_PERSISTED = 3

class DisplayTaskSignalKind(enum.IntEnum):
    ON_PRESENT_FLIP_AWAY = 0
    ON_PRESENT_FLIP_TO = 1

class DisplayWireFormatColorSpace(enum.IntEnum):
    B_T709 = 0
    B_T2020 = 1
    PROFILE_DEFINED_WIDE_COLOR_GAMUT = 2

class DisplayWireFormatEotf(enum.IntEnum):
    SDR = 0
    HDR_SMPTE2084 = 1

class DisplayWireFormatHdrMetadata(enum.IntEnum):
    NONE = 0
    HDR10 = 1
    HDR10_PLUS = 2
    DOLBY_VISION_LOW_LATENCY = 3

class DisplayWireFormatPixelEncoding(enum.IntEnum):
    RGB444 = 0
    YCC444 = 1
    YCC422 = 2
    YCC420 = 3
    INTENSITY = 4

Self = typing.TypeVar('Self')

class DisplayPresentationRate:
    vertical_sync_rate: winsdk.windows.foundation.numerics.Rational
    vertical_syncs_per_presentation: winsdk.system.Int32
    def __new__(cls: typing.Type[DisplayPresentationRate], vertical_sync_rate: winsdk.windows.foundation.numerics.Rational, vertical_syncs_per_presentation: winsdk.system.Int32) -> DisplayPresentationRate: ...

class DisplayAdapter(winsdk.system.Object):
    device_interface_path: str
    id: winsdk.windows.graphics.DisplayAdapterId
    pci_device_id: winsdk.system.UInt32
    pci_revision: winsdk.system.UInt32
    pci_sub_system_id: winsdk.system.UInt32
    pci_vendor_id: winsdk.system.UInt32
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    source_count: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayAdapter: ...
    @staticmethod
    def from_id(id: winsdk.windows.graphics.DisplayAdapterId) -> typing.Optional[DisplayAdapter]: ...

class DisplayDevice(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayDevice: ...
    def create_periodic_fence(self, target: typing.Optional[DisplayTarget], offset_from_v_blank: datetime.timedelta) -> typing.Optional[DisplayFence]: ...
    def create_primary(self, target: typing.Optional[DisplayTarget], desc: typing.Optional[DisplayPrimaryDescription]) -> typing.Optional[DisplaySurface]: ...
    def create_scanout_source(self, target: typing.Optional[DisplayTarget]) -> typing.Optional[DisplaySource]: ...
    def create_simple_scanout(self, p_source: typing.Optional[DisplaySource], p_surface: typing.Optional[DisplaySurface], sub_resource_index: winsdk.system.UInt32, sync_interval: winsdk.system.UInt32) -> typing.Optional[DisplayScanout]: ...
    def create_simple_scanout_with_dirty_rects_and_options(self, source: typing.Optional[DisplaySource], surface: typing.Optional[DisplaySurface], subresource_index: winsdk.system.UInt32, sync_interval: winsdk.system.UInt32, dirty_rects: typing.Iterable[winsdk.windows.graphics.RectInt32], options: DisplayScanoutOptions) -> typing.Optional[DisplayScanout]: ...
    def create_task_pool(self) -> typing.Optional[DisplayTaskPool]: ...
    def is_capability_supported(self, capability: DisplayDeviceCapability) -> winsdk.system.Boolean: ...
    def wait_for_v_blank(self, source: typing.Optional[DisplaySource]) -> None: ...

class DisplayFence(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayFence: ...

class DisplayManager(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayManager: ...
    def close(self) -> None: ...
    @staticmethod
    def create(options: DisplayManagerOptions) -> typing.Optional[DisplayManager]: ...
    def create_display_device(self, adapter: typing.Optional[DisplayAdapter]) -> typing.Optional[DisplayDevice]: ...
    def get_current_adapters(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[DisplayAdapter]]: ...
    def get_current_targets(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[DisplayTarget]]: ...
    def release_target(self, target: typing.Optional[DisplayTarget]) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    def try_acquire_target(self, target: typing.Optional[DisplayTarget]) -> DisplayManagerResult: ...
    def try_acquire_targets_and_create_empty_state(self, targets: typing.Iterable[DisplayTarget]) -> typing.Optional[DisplayManagerResultWithState]: ...
    def try_acquire_targets_and_create_substate(self, existing_state: typing.Optional[DisplayState], targets: typing.Iterable[DisplayTarget]) -> typing.Optional[DisplayManagerResultWithState]: ...
    def try_acquire_targets_and_read_current_state(self, targets: typing.Iterable[DisplayTarget]) -> typing.Optional[DisplayManagerResultWithState]: ...
    def try_read_current_state_for_all_targets(self) -> typing.Optional[DisplayManagerResultWithState]: ...
    def add_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[DisplayManager, DisplayManagerChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_disabled(self, handler: winsdk.windows.foundation.TypedEventHandler[DisplayManager, DisplayManagerDisabledEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_disabled(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_enabled(self, handler: winsdk.windows.foundation.TypedEventHandler[DisplayManager, DisplayManagerEnabledEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_enabled(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_paths_failed_or_invalidated(self, handler: winsdk.windows.foundation.TypedEventHandler[DisplayManager, DisplayManagerPathsFailedOrInvalidatedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_paths_failed_or_invalidated(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DisplayManagerChangedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayManagerChangedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class DisplayManagerDisabledEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayManagerDisabledEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class DisplayManagerEnabledEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayManagerEnabledEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class DisplayManagerPathsFailedOrInvalidatedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayManagerPathsFailedOrInvalidatedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class DisplayManagerResultWithState(winsdk.system.Object):
    error_code: DisplayManagerResult
    extended_error_code: winsdk.windows.foundation.HResult
    state: typing.Optional[DisplayState]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayManagerResultWithState: ...

class DisplayModeInfo(winsdk.system.Object):
    is_interlaced: winsdk.system.Boolean
    is_stereo: winsdk.system.Boolean
    presentation_rate: DisplayPresentationRate
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    source_pixel_format: winsdk.windows.graphics.directx.DirectXPixelFormat
    source_resolution: winsdk.windows.graphics.SizeInt32
    target_resolution: winsdk.windows.graphics.SizeInt32
    physical_presentation_rate: DisplayPresentationRate
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayModeInfo: ...
    def get_wire_format_supported_bits_per_channel(self, encoding: DisplayWireFormatPixelEncoding) -> DisplayBitsPerChannel: ...
    def is_wire_format_supported(self, wire_format: typing.Optional[DisplayWireFormat]) -> winsdk.system.Boolean: ...

class DisplayPath(winsdk.system.Object):
    wire_format: typing.Optional[DisplayWireFormat]
    target_resolution: typing.Optional[typing.Optional[winsdk.windows.graphics.SizeInt32]]
    source_resolution: typing.Optional[typing.Optional[winsdk.windows.graphics.SizeInt32]]
    source_pixel_format: winsdk.windows.graphics.directx.DirectXPixelFormat
    scaling: DisplayPathScaling
    rotation: DisplayRotation
    presentation_rate: typing.Optional[typing.Optional[DisplayPresentationRate]]
    is_stereo: winsdk.system.Boolean
    is_interlaced: typing.Optional[typing.Optional[winsdk.system.Boolean]]
    properties: typing.Optional[winsdk.windows.foundation.collections.IMap[winsdk.system.Guid, winsdk.system.Object]]
    status: DisplayPathStatus
    target: typing.Optional[DisplayTarget]
    view: typing.Optional[DisplayView]
    physical_presentation_rate: typing.Optional[typing.Optional[DisplayPresentationRate]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayPath: ...
    def apply_properties_from_mode(self, mode_result: typing.Optional[DisplayModeInfo]) -> None: ...
    def find_modes(self, flags: DisplayModeQueryOptions) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[DisplayModeInfo]]: ...

class DisplayPrimaryDescription(winsdk.system.Object):
    color_space: winsdk.windows.graphics.directx.DirectXColorSpace
    format: winsdk.windows.graphics.directx.DirectXPixelFormat
    height: winsdk.system.UInt32
    is_stereo: winsdk.system.Boolean
    multisample_description: winsdk.windows.graphics.directx.direct3d11.Direct3DMultisampleDescription
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    width: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayPrimaryDescription: ...
    def __new__(cls: typing.Type[DisplayPrimaryDescription], width: winsdk.system.UInt32, height: winsdk.system.UInt32, pixel_format: winsdk.windows.graphics.directx.DirectXPixelFormat, color_space: winsdk.windows.graphics.directx.DirectXColorSpace, is_stereo: winsdk.system.Boolean, multisample_description: winsdk.windows.graphics.directx.direct3d11.Direct3DMultisampleDescription) -> DisplayPrimaryDescription:...
    @staticmethod
    def create_with_properties(extra_properties: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[winsdk.system.Guid, winsdk.system.Object]], width: winsdk.system.UInt32, height: winsdk.system.UInt32, pixel_format: winsdk.windows.graphics.directx.DirectXPixelFormat, color_space: winsdk.windows.graphics.directx.DirectXColorSpace, is_stereo: winsdk.system.Boolean, multisample_description: winsdk.windows.graphics.directx.direct3d11.Direct3DMultisampleDescription) -> typing.Optional[DisplayPrimaryDescription]: ...

class DisplayScanout(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayScanout: ...

class DisplaySource(winsdk.system.Object):
    adapter_id: winsdk.windows.graphics.DisplayAdapterId
    source_id: winsdk.system.UInt32
    status: DisplaySourceStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplaySource: ...
    def get_metadata(self, key: winsdk.system.Guid) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    def add_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[DisplaySource, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DisplayState(winsdk.system.Object):
    is_read_only: winsdk.system.Boolean
    is_stale: winsdk.system.Boolean
    properties: typing.Optional[winsdk.windows.foundation.collections.IMap[winsdk.system.Guid, winsdk.system.Object]]
    targets: typing.Optional[winsdk.windows.foundation.collections.IVectorView[DisplayTarget]]
    views: typing.Optional[winsdk.windows.foundation.collections.IVectorView[DisplayView]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayState: ...
    def can_connect_target_to_view(self, target: typing.Optional[DisplayTarget], view: typing.Optional[DisplayView]) -> winsdk.system.Boolean: ...
    def clone(self) -> typing.Optional[DisplayState]: ...
    @typing.overload
    def connect_target(self, target: typing.Optional[DisplayTarget]) -> typing.Optional[DisplayPath]: ...
    @typing.overload
    def connect_target(self, target: typing.Optional[DisplayTarget], view: typing.Optional[DisplayView]) -> typing.Optional[DisplayPath]: ...
    def disconnect_target(self, target: typing.Optional[DisplayTarget]) -> None: ...
    def get_path_for_target(self, target: typing.Optional[DisplayTarget]) -> typing.Optional[DisplayPath]: ...
    def get_view_for_target(self, target: typing.Optional[DisplayTarget]) -> typing.Optional[DisplayView]: ...
    def try_apply(self, options: DisplayStateApplyOptions) -> typing.Optional[DisplayStateOperationResult]: ...
    def try_functionalize(self, options: DisplayStateFunctionalizeOptions) -> typing.Optional[DisplayStateOperationResult]: ...

class DisplayStateOperationResult(winsdk.system.Object):
    extended_error_code: winsdk.windows.foundation.HResult
    status: DisplayStateOperationStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayStateOperationResult: ...

class DisplaySurface(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplaySurface: ...

class DisplayTarget(winsdk.system.Object):
    adapter: typing.Optional[DisplayAdapter]
    adapter_relative_id: winsdk.system.UInt32
    device_interface_path: str
    is_connected: winsdk.system.Boolean
    is_stale: winsdk.system.Boolean
    is_virtual_mode_enabled: winsdk.system.Boolean
    is_virtual_topology_enabled: winsdk.system.Boolean
    monitor_persistence: DisplayTargetPersistence
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    stable_monitor_id: str
    usage_kind: winsdk.windows.devices.display.DisplayMonitorUsageKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayTarget: ...
    def is_equal(self, other_target: typing.Optional[DisplayTarget]) -> winsdk.system.Boolean: ...
    def is_same(self, other_target: typing.Optional[DisplayTarget]) -> winsdk.system.Boolean: ...
    def try_get_monitor(self) -> typing.Optional[winsdk.windows.devices.display.DisplayMonitor]: ...

class DisplayTask(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayTask: ...
    def set_scanout(self, scanout: typing.Optional[DisplayScanout]) -> None: ...
    def set_signal(self, signal_kind: DisplayTaskSignalKind, fence: typing.Optional[DisplayFence]) -> None: ...
    def set_wait(self, ready_fence: typing.Optional[DisplayFence], ready_fence_value: winsdk.system.UInt64) -> None: ...

class DisplayTaskPool(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayTaskPool: ...
    def create_task(self) -> typing.Optional[DisplayTask]: ...
    def execute_task(self, task: typing.Optional[DisplayTask]) -> None: ...
    def try_execute_task(self, task: typing.Optional[DisplayTask]) -> typing.Optional[DisplayTaskResult]: ...

class DisplayTaskResult(winsdk.system.Object):
    present_id: winsdk.system.UInt64
    present_status: DisplayPresentStatus
    source_status: DisplaySourceStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayTaskResult: ...

class DisplayView(winsdk.system.Object):
    content_resolution: typing.Optional[typing.Optional[winsdk.windows.graphics.SizeInt32]]
    paths: typing.Optional[winsdk.windows.foundation.collections.IVectorView[DisplayPath]]
    properties: typing.Optional[winsdk.windows.foundation.collections.IMap[winsdk.system.Guid, winsdk.system.Object]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayView: ...
    def set_primary_path(self, path: typing.Optional[DisplayPath]) -> None: ...

class DisplayWireFormat(winsdk.system.Object):
    bits_per_channel: winsdk.system.Int32
    color_space: DisplayWireFormatColorSpace
    eotf: DisplayWireFormatEotf
    hdr_metadata: DisplayWireFormatHdrMetadata
    pixel_encoding: DisplayWireFormatPixelEncoding
    properties: typing.Optional[winsdk.windows.foundation.collections.IMapView[winsdk.system.Guid, winsdk.system.Object]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayWireFormat: ...
    def __new__(cls: typing.Type[DisplayWireFormat], pixel_encoding: DisplayWireFormatPixelEncoding, bits_per_channel: winsdk.system.Int32, color_space: DisplayWireFormatColorSpace, eotf: DisplayWireFormatEotf, hdr_metadata: DisplayWireFormatHdrMetadata) -> DisplayWireFormat:...
    @staticmethod
    def create_with_properties(extra_properties: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[winsdk.system.Guid, winsdk.system.Object]], pixel_encoding: DisplayWireFormatPixelEncoding, bits_per_channel: winsdk.system.Int32, color_space: DisplayWireFormatColorSpace, eotf: DisplayWireFormatEotf, hdr_metadata: DisplayWireFormatHdrMetadata) -> typing.Optional[DisplayWireFormat]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.datatransfer
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams
import winsdk.windows.ui
import winsdk.windows.web
import winsdk.windows.web.http

class WebViewControlPermissionState(enum.IntEnum):
    UNKNOWN = 0
    DEFER = 1
    ALLOW = 2
    DENY = 3

class WebViewControlPermissionType(enum.IntEnum):
    GEOLOCATION = 0
    UNLIMITED_INDEXED_D_B_QUOTA = 1
    MEDIA = 2
    POINTER_LOCK = 3
    WEB_NOTIFICATIONS = 4
    SCREEN = 5
    IMMERSIVE_VIEW = 6

Self = typing.TypeVar('Self')

class WebViewControlContentLoadingEventArgs(winsdk.system.Object):
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlContentLoadingEventArgs: ...

class WebViewControlDOMContentLoadedEventArgs(winsdk.system.Object):
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlDOMContentLoadedEventArgs: ...

class WebViewControlDeferredPermissionRequest(winsdk.system.Object):
    id: winsdk.system.UInt32
    permission_type: WebViewControlPermissionType
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlDeferredPermissionRequest: ...
    def allow(self) -> None: ...
    def deny(self) -> None: ...

class WebViewControlLongRunningScriptDetectedEventArgs(winsdk.system.Object):
    stop_page_script_execution: winsdk.system.Boolean
    execution_time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlLongRunningScriptDetectedEventArgs: ...

class WebViewControlNavigationCompletedEventArgs(winsdk.system.Object):
    is_success: winsdk.system.Boolean
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    web_error_status: winsdk.windows.web.WebErrorStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlNavigationCompletedEventArgs: ...

class WebViewControlNavigationStartingEventArgs(winsdk.system.Object):
    cancel: winsdk.system.Boolean
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlNavigationStartingEventArgs: ...

class WebViewControlNewWindowRequestedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    referrer: typing.Optional[winsdk.windows.foundation.Uri]
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    new_window: typing.Optional[IWebViewControl]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlNewWindowRequestedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class WebViewControlPermissionRequest(winsdk.system.Object):
    id: winsdk.system.UInt32
    permission_type: WebViewControlPermissionType
    state: WebViewControlPermissionState
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlPermissionRequest: ...
    def allow(self) -> None: ...
    def defer(self) -> None: ...
    def deny(self) -> None: ...

class WebViewControlPermissionRequestedEventArgs(winsdk.system.Object):
    permission_request: typing.Optional[WebViewControlPermissionRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlPermissionRequestedEventArgs: ...

class WebViewControlScriptNotifyEventArgs(winsdk.system.Object):
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    value: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlScriptNotifyEventArgs: ...

class WebViewControlSettings(winsdk.system.Object):
    is_script_notify_allowed: winsdk.system.Boolean
    is_java_script_enabled: winsdk.system.Boolean
    is_indexed_d_b_enabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlSettings: ...

class WebViewControlUnsupportedUriSchemeIdentifiedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlUnsupportedUriSchemeIdentifiedEventArgs: ...

class WebViewControlUnviewableContentIdentifiedEventArgs(winsdk.system.Object):
    media_type: str
    referrer: typing.Optional[winsdk.windows.foundation.Uri]
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlUnviewableContentIdentifiedEventArgs: ...

class WebViewControlWebResourceRequestedEventArgs(winsdk.system.Object):
    response: typing.Optional[winsdk.windows.web.http.HttpResponseMessage]
    request: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebViewControlWebResourceRequestedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class IWebViewControl(winsdk.system.Object):
    can_go_back: winsdk.system.Boolean
    can_go_forward: winsdk.system.Boolean
    contains_full_screen_element: winsdk.system.Boolean
    default_background_color: winsdk.windows.ui.Color
    deferred_permission_requests: typing.Optional[winsdk.windows.foundation.collections.IVectorView[WebViewControlDeferredPermissionRequest]]
    document_title: str
    settings: typing.Optional[WebViewControlSettings]
    source: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebViewControl: ...
    def build_local_stream_uri(self, content_identifier: str, relative_path: str) -> typing.Optional[winsdk.windows.foundation.Uri]: ...
    def capture_preview_to_stream_async(self, stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    def capture_selected_content_to_data_package_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.applicationmodel.datatransfer.DataPackage]: ...
    def get_deferred_permission_request_by_id(self, id: winsdk.system.UInt32) -> typing.Optional[WebViewControlDeferredPermissionRequest]: ...
    def go_back(self) -> None: ...
    def go_forward(self) -> None: ...
    def invoke_script_async(self, script_name: str, arguments: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    def navigate(self, source: typing.Optional[winsdk.windows.foundation.Uri]) -> None: ...
    def navigate_to_local_stream_uri(self, source: typing.Optional[winsdk.windows.foundation.Uri], stream_resolver: typing.Optional[winsdk.windows.web.IUriToStreamResolver]) -> None: ...
    def navigate_to_string(self, text: str) -> None: ...
    def navigate_with_http_request_message(self, request_message: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]) -> None: ...
    def refresh(self) -> None: ...
    def stop(self) -> None: ...
    def add_contains_full_screen_element_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_contains_full_screen_element_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_content_loading(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlContentLoadingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_content_loading(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_d_o_m_content_loaded(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlDOMContentLoadedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_d_o_m_content_loaded(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_content_loading(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlContentLoadingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_content_loading(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_d_o_m_content_loaded(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlDOMContentLoadedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_d_o_m_content_loaded(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_navigation_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlNavigationCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_navigation_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_frame_navigation_starting(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlNavigationStartingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_frame_navigation_starting(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_long_running_script_detected(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlLongRunningScriptDetectedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_long_running_script_detected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_navigation_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlNavigationCompletedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_navigation_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_navigation_starting(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlNavigationStartingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_navigation_starting(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_new_window_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlNewWindowRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_new_window_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_permission_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlPermissionRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_permission_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_script_notify(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlScriptNotifyEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_script_notify(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_unsafe_content_warning_displaying(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unsafe_content_warning_displaying(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_unsupported_uri_scheme_identified(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlUnsupportedUriSchemeIdentifiedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unsupported_uri_scheme_identified(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_unviewable_content_identified(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlUnviewableContentIdentifiedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_unviewable_content_identified(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_web_resource_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[IWebViewControl, WebViewControlWebResourceRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_web_resource_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class IWebViewControl2(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebViewControl2: ...
    def add_initialize_script(self, script: str) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections

Self = typing.TypeVar('Self')

class EnterpriseKeyCredentialRegistrationInfo(winsdk.system.Object):
    key_id: str
    key_name: str
    subject: str
    tenant_id: str
    tenant_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnterpriseKeyCredentialRegistrationInfo: ...

class EnterpriseKeyCredentialRegistrationManager(winsdk.system.Object):
    current: typing.ClassVar[typing.Optional[EnterpriseKeyCredentialRegistrationManager]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> EnterpriseKeyCredentialRegistrationManager: ...
    def get_registrations_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[EnterpriseKeyCredentialRegistrationInfo]]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.UserDataTasks")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class UserDataTaskDaysOfWeek(enum.IntFlag):
    NONE = 0
    SUNDAY = 0x1
    MONDAY = 0x2
    TUESDAY = 0x4
    WEDNESDAY = 0x8
    THURSDAY = 0x10
    FRIDAY = 0x20
    SATURDAY = 0x40

class UserDataTaskDetailsKind(enum.IntEnum):
    PLAIN_TEXT = 0
    HTML = 1

class UserDataTaskKind(enum.IntEnum):
    SINGLE = 0
    RECURRING = 1
    REGENERATING = 2

class UserDataTaskListOtherAppReadAccess(enum.IntEnum):
    FULL = 0
    SYSTEM_ONLY = 1
    NONE = 2

class UserDataTaskListOtherAppWriteAccess(enum.IntEnum):
    LIMITED = 0
    NONE = 1

class UserDataTaskListSyncStatus(enum.IntEnum):
    IDLE = 0
    SYNCING = 1
    UP_TO_DATE = 2
    AUTHENTICATION_ERROR = 3
    POLICY_ERROR = 4
    UNKNOWN_ERROR = 5

class UserDataTaskPriority(enum.IntEnum):
    NORMAL = 0
    LOW = -1
    HIGH = 1

class UserDataTaskQueryKind(enum.IntEnum):
    ALL = 0
    INCOMPLETE = 1
    COMPLETE = 2

class UserDataTaskQuerySortProperty(enum.IntEnum):
    DUE_DATE = 0

class UserDataTaskRecurrenceUnit(enum.IntEnum):
    DAILY = 0
    WEEKLY = 1
    MONTHLY = 2
    MONTHLY_ON_DAY = 3
    YEARLY = 4
    YEARLY_ON_DAY = 5

class UserDataTaskRegenerationUnit(enum.IntEnum):
    DAILY = 0
    WEEKLY = 1
    MONTHLY = 2
    YEARLY = 4

class UserDataTaskSensitivity(enum.IntEnum):
    PUBLIC = 0
    PRIVATE = 1

class UserDataTaskStoreAccessType(enum.IntEnum):
    APP_TASKS_READ_WRITE = 0
    ALL_TASKS_LIMITED_READ_WRITE = 1

class UserDataTaskWeekOfMonth(enum.IntEnum):
    FIRST = 0
    SECOND = 1
    THIRD = 2
    FOURTH = 3
    LAST = 4

_ns_module._register_UserDataTaskDaysOfWeek(UserDataTaskDaysOfWeek)
_ns_module._register_UserDataTaskDetailsKind(UserDataTaskDetailsKind)
_ns_module._register_UserDataTaskKind(UserDataTaskKind)
_ns_module._register_UserDataTaskListOtherAppReadAccess(UserDataTaskListOtherAppReadAccess)
_ns_module._register_UserDataTaskListOtherAppWriteAccess(UserDataTaskListOtherAppWriteAccess)
_ns_module._register_UserDataTaskListSyncStatus(UserDataTaskListSyncStatus)
_ns_module._register_UserDataTaskPriority(UserDataTaskPriority)
_ns_module._register_UserDataTaskQueryKind(UserDataTaskQueryKind)
_ns_module._register_UserDataTaskQuerySortProperty(UserDataTaskQuerySortProperty)
_ns_module._register_UserDataTaskRecurrenceUnit(UserDataTaskRecurrenceUnit)
_ns_module._register_UserDataTaskRegenerationUnit(UserDataTaskRegenerationUnit)
_ns_module._register_UserDataTaskSensitivity(UserDataTaskSensitivity)
_ns_module._register_UserDataTaskStoreAccessType(UserDataTaskStoreAccessType)
_ns_module._register_UserDataTaskWeekOfMonth(UserDataTaskWeekOfMonth)

UserDataTask = _ns_module.UserDataTask
UserDataTaskBatch = _ns_module.UserDataTaskBatch
UserDataTaskList = _ns_module.UserDataTaskList
UserDataTaskListLimitedWriteOperations = _ns_module.UserDataTaskListLimitedWriteOperations
UserDataTaskListSyncManager = _ns_module.UserDataTaskListSyncManager
UserDataTaskManager = _ns_module.UserDataTaskManager
UserDataTaskQueryOptions = _ns_module.UserDataTaskQueryOptions
UserDataTaskReader = _ns_module.UserDataTaskReader
UserDataTaskRecurrenceProperties = _ns_module.UserDataTaskRecurrenceProperties
UserDataTaskRegenerationProperties = _ns_module.UserDataTaskRegenerationProperties
UserDataTaskStore = _ns_module.UserDataTaskStore



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Core.Preview.Communications")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

class PreviewMeetingInfoDisplayKind(enum.IntEnum):
    ORGANIZER_AND_TIME = 0
    ORGANIZER_TIME_AND_TITLE = 1

class PreviewSystemState(enum.IntEnum):
    PREPARING = 0
    REBOOTING = 1
    ERROR = 2
    SESSION_PAUSED = 3
    READY = 4

class PreviewTeamEndMeetingKind(enum.IntEnum):
    SHOW_DEFAULT_VIEW = 0
    CLOSE_VIEW = 1

class PreviewTeamViewCommand(enum.IntEnum):
    TOGGLE_CALL_CONTROL = 0
    SHOW_PEOPLE = 1
    SHOW_MESSAGING = 2
    SHOW_CONTENT = 3
    TOGGLE_MICROPHONE = 4
    TOGGLE_CAMERA = 5
    SHOW_CALENDAR = 6
    TOGGLE_SCREEN_SHARING = 7
    TOGGLE_FULL_SCREEN = 8

_ns_module._register_PreviewMeetingInfoDisplayKind(PreviewMeetingInfoDisplayKind)
_ns_module._register_PreviewSystemState(PreviewSystemState)
_ns_module._register_PreviewTeamEndMeetingKind(PreviewTeamEndMeetingKind)
_ns_module._register_PreviewTeamViewCommand(PreviewTeamViewCommand)

PreviewTeamCleanupRequestedEventArgs = _ns_module.PreviewTeamCleanupRequestedEventArgs
PreviewTeamCommandInvokedEventArgs = _ns_module.PreviewTeamCommandInvokedEventArgs
PreviewTeamDeviceCredentials = _ns_module.PreviewTeamDeviceCredentials
PreviewTeamEndMeetingRequestedEventArgs = _ns_module.PreviewTeamEndMeetingRequestedEventArgs
PreviewTeamJoinMeetingRequestedEventArgs = _ns_module.PreviewTeamJoinMeetingRequestedEventArgs
PreviewTeamView = _ns_module.PreviewTeamView



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import array
import types
import typing
import sys

MTA: int
STA: int

def init_apartment(apartment_type: int) -> None: ...
def uninit_apartment() -> None: ...
def initialize_with_window(obj: Object, hwnd: int) -> None: ...

class Object: ...

_Self = typing.TypeVar("_Self")
_T = typing.TypeVar("_T")

class Array(typing.MutableSequence[_T]):
    _winrt_element_type_name_: str
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, key: typing.Any) -> types.GenericAlias: ...

    @typing.overload
    def __new__(
        cls: typing.Type[_Self],
        __type: typing.Union[typing.Type[_T], str],
        __size: int,
        /,
    ) -> _Self: ...
    @typing.overload
    def __new__(
        cls: typing.Type[_Self],
        __type: typing.Union[typing.Type[_T], str],
        __initializer: memoryview,
        /,
    ) -> _Self: ...
    @typing.overload
    def __new__(
        cls: typing.Type[_Self], __type: str, __initializer: array.array, /
    ) -> _Self: ...
    @typing.overload
    def __new__(
        cls: typing.Type[_Self],
        __type: typing.Union[typing.Type[_T], str],
        __initializer: Array[_T],
        /,
    ) -> _Self: ...
    @typing.overload
    def __new__(
        cls: typing.Type[_Self],
        __type: typing.Union[typing.Type[_T], str],
        __initializer: typing.List[_T],
        /,
    ) -> _Self: ...
    @typing.overload
    def __new__(
        cls: typing.Type[_Self],
        __type: typing.Union[typing.Type[_T], str],
        __initializer: typing.Tuple[_T],
        /,
    ) -> _Self: ...
    def __len__(self) -> int: ...
    @typing.overload
    def __getitem__(self, index: typing.SupportsIndex) -> _T: ...
    @typing.overload
    def __getitem__(self, index: slice) -> typing.MutableSequence[_T]: ...
    @typing.overload
    def __setitem__(self, index: typing.SupportsIndex, value: _T) -> None: ...
    @typing.overload
    def __setitem__(self, index: slice, value: typing.Iterable[_T]) -> None: ...
    @typing.overload
    def __delitem__(self, index: typing.SupportsIndex) -> None: ...
    @typing.overload
    def __delitem__(self, index: slice) -> None: ...
    def insert(self, index: typing.SupportsIndex, value: _T) -> None: ...



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.System.Diagnostics.TraceReporting")

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class PlatformDiagnosticActionState(enum.IntEnum):
    SUCCESS = 0
    FREE_NETWORK_NOT_AVAILABLE = 1
    A_C_POWER_NOT_AVAILABLE = 2

class PlatformDiagnosticEscalationType(enum.IntEnum):
    ON_COMPLETION = 0
    ON_FAILURE = 1

class PlatformDiagnosticEventBufferLatencies(enum.IntFlag):
    NORMAL = 0x1
    COST_DEFERRED = 0x2
    REALTIME = 0x4

class PlatformDiagnosticTracePriority(enum.IntEnum):
    NORMAL = 0
    USER_ELEVATED = 1

class PlatformDiagnosticTraceSlotState(enum.IntEnum):
    NOT_RUNNING = 0
    RUNNING = 1
    THROTTLED = 2

class PlatformDiagnosticTraceSlotType(enum.IntEnum):
    ALTERNATIVE = 0
    ALWAYS_ON = 1
    MINI = 2

_ns_module._register_PlatformDiagnosticActionState(PlatformDiagnosticActionState)
_ns_module._register_PlatformDiagnosticEscalationType(PlatformDiagnosticEscalationType)
_ns_module._register_PlatformDiagnosticEventBufferLatencies(PlatformDiagnosticEventBufferLatencies)
_ns_module._register_PlatformDiagnosticTracePriority(PlatformDiagnosticTracePriority)
_ns_module._register_PlatformDiagnosticTraceSlotState(PlatformDiagnosticTraceSlotState)
_ns_module._register_PlatformDiagnosticTraceSlotType(PlatformDiagnosticTraceSlotType)

PlatformDiagnosticActions = _ns_module.PlatformDiagnosticActions
PlatformDiagnosticTraceInfo = _ns_module.PlatformDiagnosticTraceInfo
PlatformDiagnosticTraceRuntimeInfo = _ns_module.PlatformDiagnosticTraceRuntimeInfo



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Phone.System.UserProfile.GameServices.Core")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class GameServiceGameOutcome(enum.IntEnum):
    NONE = 0
    WIN = 1
    LOSS = 2
    TIE = 3

class GameServiceScoreKind(enum.IntEnum):
    NUMBER = 0
    TIME = 1

_ns_module._register_GameServiceGameOutcome(GameServiceGameOutcome)
_ns_module._register_GameServiceScoreKind(GameServiceScoreKind)

GameService = _ns_module.GameService
GameServicePropertyCollection = _ns_module.GameServicePropertyCollection



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Pwm")

try:
    import winsdk.windows.devices.pwm.provider
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class PwmPulsePolarity(enum.IntEnum):
    ACTIVE_HIGH = 0
    ACTIVE_LOW = 1

_ns_module._register_PwmPulsePolarity(PwmPulsePolarity)

PwmController = _ns_module.PwmController
PwmPin = _ns_module.PwmPin



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Display")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.graphics
except ImportError:
    pass

class DisplayMonitorConnectionKind(enum.IntEnum):
    INTERNAL = 0
    WIRED = 1
    WIRELESS = 2
    VIRTUAL = 3

class DisplayMonitorDescriptorKind(enum.IntEnum):
    EDID = 0
    DISPLAY_ID = 1

class DisplayMonitorPhysicalConnectorKind(enum.IntEnum):
    UNKNOWN = 0
    H_D15 = 1
    ANALOG_T_V = 2
    DVI = 3
    HDMI = 4
    LVDS = 5
    SDI = 6
    DISPLAY_PORT = 7

class DisplayMonitorUsageKind(enum.IntEnum):
    STANDARD = 0
    HEAD_MOUNTED = 1
    SPECIAL_PURPOSE = 2

_ns_module._register_DisplayMonitorConnectionKind(DisplayMonitorConnectionKind)
_ns_module._register_DisplayMonitorDescriptorKind(DisplayMonitorDescriptorKind)
_ns_module._register_DisplayMonitorPhysicalConnectorKind(DisplayMonitorPhysicalConnectorKind)
_ns_module._register_DisplayMonitorUsageKind(DisplayMonitorUsageKind)

DisplayMonitor = _ns_module.DisplayMonitor



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Storage.Provider")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class CachedFileOptions(enum.IntFlag):
    NONE = 0
    REQUIRE_UPDATE_ON_ACCESS = 0x1
    USE_CACHED_FILE_WHEN_OFFLINE = 0x2
    DENY_ACCESS_WHEN_OFFLINE = 0x4

class CachedFileTarget(enum.IntEnum):
    LOCAL = 0
    REMOTE = 1

class FileUpdateStatus(enum.IntEnum):
    INCOMPLETE = 0
    COMPLETE = 1
    USER_INPUT_NEEDED = 2
    CURRENTLY_UNAVAILABLE = 3
    FAILED = 4
    COMPLETE_AND_RENAMED = 5

class ReadActivationMode(enum.IntEnum):
    NOT_NEEDED = 0
    BEFORE_ACCESS = 1

class StorageProviderHardlinkPolicy(enum.IntFlag):
    NONE = 0
    ALLOWED = 0x1

class StorageProviderHydrationPolicy(enum.IntEnum):
    PARTIAL = 0
    PROGRESSIVE = 1
    FULL = 2
    ALWAYS_FULL = 3

class StorageProviderHydrationPolicyModifier(enum.IntFlag):
    NONE = 0
    VALIDATION_REQUIRED = 0x1
    STREAMING_ALLOWED = 0x2
    AUTO_DEHYDRATION_ALLOWED = 0x4
    ALLOW_FULL_RESTART_HYDRATION = 0x8

class StorageProviderInSyncPolicy(enum.IntFlag):
    DEFAULT = 0
    FILE_CREATION_TIME = 0x1
    FILE_READ_ONLY_ATTRIBUTE = 0x2
    FILE_HIDDEN_ATTRIBUTE = 0x4
    FILE_SYSTEM_ATTRIBUTE = 0x8
    DIRECTORY_CREATION_TIME = 0x10
    DIRECTORY_READ_ONLY_ATTRIBUTE = 0x20
    DIRECTORY_HIDDEN_ATTRIBUTE = 0x40
    DIRECTORY_SYSTEM_ATTRIBUTE = 0x80
    FILE_LAST_WRITE_TIME = 0x100
    DIRECTORY_LAST_WRITE_TIME = 0x200
    PRESERVE_INSYNC_FOR_SYNC_ENGINE = 0x80000000

class StorageProviderPopulationPolicy(enum.IntEnum):
    FULL = 1
    ALWAYS_FULL = 2

class StorageProviderProtectionMode(enum.IntEnum):
    UNKNOWN = 0
    PERSONAL = 1

class StorageProviderState(enum.IntEnum):
    IN_SYNC = 0
    SYNCING = 1
    PAUSED = 2
    ERROR = 3
    WARNING = 4
    OFFLINE = 5

class StorageProviderUICommandState(enum.IntEnum):
    ENABLED = 0
    DISABLED = 1
    HIDDEN = 2

class StorageProviderUriSourceStatus(enum.IntEnum):
    SUCCESS = 0
    NO_SYNC_ROOT = 1
    FILE_NOT_FOUND = 2

class UIStatus(enum.IntEnum):
    UNAVAILABLE = 0
    HIDDEN = 1
    VISIBLE = 2
    COMPLETE = 3

class WriteActivationMode(enum.IntEnum):
    READ_ONLY = 0
    NOT_NEEDED = 1
    AFTER_WRITE = 2

_ns_module._register_CachedFileOptions(CachedFileOptions)
_ns_module._register_CachedFileTarget(CachedFileTarget)
_ns_module._register_FileUpdateStatus(FileUpdateStatus)
_ns_module._register_ReadActivationMode(ReadActivationMode)
_ns_module._register_StorageProviderHardlinkPolicy(StorageProviderHardlinkPolicy)
_ns_module._register_StorageProviderHydrationPolicy(StorageProviderHydrationPolicy)
_ns_module._register_StorageProviderHydrationPolicyModifier(StorageProviderHydrationPolicyModifier)
_ns_module._register_StorageProviderInSyncPolicy(StorageProviderInSyncPolicy)
_ns_module._register_StorageProviderPopulationPolicy(StorageProviderPopulationPolicy)
_ns_module._register_StorageProviderProtectionMode(StorageProviderProtectionMode)
_ns_module._register_StorageProviderState(StorageProviderState)
_ns_module._register_StorageProviderUICommandState(StorageProviderUICommandState)
_ns_module._register_StorageProviderUriSourceStatus(StorageProviderUriSourceStatus)
_ns_module._register_UIStatus(UIStatus)
_ns_module._register_WriteActivationMode(WriteActivationMode)

CachedFileUpdater = _ns_module.CachedFileUpdater
CachedFileUpdaterUI = _ns_module.CachedFileUpdaterUI
FileUpdateRequest = _ns_module.FileUpdateRequest
FileUpdateRequestDeferral = _ns_module.FileUpdateRequestDeferral
FileUpdateRequestedEventArgs = _ns_module.FileUpdateRequestedEventArgs
StorageProviderFileTypeInfo = _ns_module.StorageProviderFileTypeInfo
StorageProviderGetContentInfoForPathResult = _ns_module.StorageProviderGetContentInfoForPathResult
StorageProviderGetPathForContentUriResult = _ns_module.StorageProviderGetPathForContentUriResult
StorageProviderItemProperties = _ns_module.StorageProviderItemProperties
StorageProviderItemProperty = _ns_module.StorageProviderItemProperty
StorageProviderItemPropertyDefinition = _ns_module.StorageProviderItemPropertyDefinition
StorageProviderMoreInfoUI = _ns_module.StorageProviderMoreInfoUI
StorageProviderQuotaUI = _ns_module.StorageProviderQuotaUI
StorageProviderStatusUI = _ns_module.StorageProviderStatusUI
StorageProviderSyncRootInfo = _ns_module.StorageProviderSyncRootInfo
StorageProviderSyncRootManager = _ns_module.StorageProviderSyncRootManager
IStorageProviderItemPropertySource = _ns_module.IStorageProviderItemPropertySource
IStorageProviderPropertyCapabilities = _ns_module.IStorageProviderPropertyCapabilities
IStorageProviderStatusUISource = _ns_module.IStorageProviderStatusUISource
IStorageProviderStatusUISourceFactory = _ns_module.IStorageProviderStatusUISourceFactory
IStorageProviderUICommand = _ns_module.IStorageProviderUICommand
IStorageProviderUriSource = _ns_module.IStorageProviderUriSource



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.system
import winsdk.windows.ui
import winsdk.windows.ui.composition

class AppWindowClosedReason(enum.IntEnum):
    OTHER = 0
    APP_INITIATED = 1
    USER_INITIATED = 2

class AppWindowFrameStyle(enum.IntEnum):
    DEFAULT = 0
    NO_FRAME = 1

class AppWindowPresentationKind(enum.IntEnum):
    DEFAULT = 0
    COMPACT_OVERLAY = 1
    FULL_SCREEN = 2

class AppWindowTitleBarVisibility(enum.IntEnum):
    DEFAULT = 0
    ALWAYS_HIDDEN = 1

class WindowingEnvironmentKind(enum.IntEnum):
    UNKNOWN = 0
    OVERLAPPED = 1
    TILED = 2

Self = typing.TypeVar('Self')

class AppWindow(winsdk.system.Object):
    title: str
    persisted_state_id: str
    content: typing.Optional[winsdk.windows.ui.UIContentRoot]
    dispatcher_queue: typing.Optional[winsdk.windows.system.DispatcherQueue]
    frame: typing.Optional[AppWindowFrame]
    is_visible: winsdk.system.Boolean
    presenter: typing.Optional[AppWindowPresenter]
    title_bar: typing.Optional[AppWindowTitleBar]
    u_i_context: typing.Optional[winsdk.windows.ui.UIContext]
    windowing_environment: typing.Optional[WindowingEnvironment]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindow: ...
    @staticmethod
    def clear_all_persisted_state() -> None: ...
    @staticmethod
    def clear_persisted_state(key: str) -> None: ...
    def close_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_display_regions(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[DisplayRegion]]: ...
    def get_placement(self) -> typing.Optional[AppWindowPlacement]: ...
    def request_move_adjacent_to_current_view(self) -> None: ...
    def request_move_adjacent_to_window(self, anchor_window: typing.Optional[AppWindow]) -> None: ...
    def request_move_relative_to_current_view_content(self, content_offset: winsdk.windows.foundation.Point) -> None: ...
    def request_move_relative_to_display_region(self, display_region: typing.Optional[DisplayRegion], display_region_offset: winsdk.windows.foundation.Point) -> None: ...
    def request_move_relative_to_window_content(self, anchor_window: typing.Optional[AppWindow], content_offset: winsdk.windows.foundation.Point) -> None: ...
    def request_move_to_display_region(self, display_region: typing.Optional[DisplayRegion]) -> None: ...
    def request_size(self, frame_size: winsdk.windows.foundation.Size) -> None: ...
    @staticmethod
    def try_create_async() -> winsdk.windows.foundation.IAsyncOperation[AppWindow]: ...
    def try_show_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def add_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppWindow, AppWindowChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_close_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[AppWindow, AppWindowCloseRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_close_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_closed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppWindow, AppWindowClosedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_closed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppWindowChangedEventArgs(winsdk.system.Object):
    did_available_window_presentations_change: winsdk.system.Boolean
    did_display_regions_change: winsdk.system.Boolean
    did_frame_change: winsdk.system.Boolean
    did_size_change: winsdk.system.Boolean
    did_title_bar_change: winsdk.system.Boolean
    did_visibility_change: winsdk.system.Boolean
    did_window_presentation_change: winsdk.system.Boolean
    did_windowing_environment_change: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindowChangedEventArgs: ...

class AppWindowCloseRequestedEventArgs(winsdk.system.Object):
    cancel: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindowCloseRequestedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class AppWindowClosedEventArgs(winsdk.system.Object):
    reason: AppWindowClosedReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindowClosedEventArgs: ...

class AppWindowFrame(winsdk.system.Object):
    drag_region_visuals: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.ui.composition.IVisualElement]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindowFrame: ...
    def get_frame_style(self) -> AppWindowFrameStyle: ...
    def set_frame_style(self, frame_style: AppWindowFrameStyle) -> None: ...

class AppWindowPlacement(winsdk.system.Object):
    display_region: typing.Optional[DisplayRegion]
    offset: winsdk.windows.foundation.Point
    size: winsdk.windows.foundation.Size
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindowPlacement: ...

class AppWindowPresentationConfiguration(winsdk.system.Object):
    kind: AppWindowPresentationKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindowPresentationConfiguration: ...

class AppWindowPresenter(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindowPresenter: ...
    def get_configuration(self) -> typing.Optional[AppWindowPresentationConfiguration]: ...
    def is_presentation_supported(self, presentation_kind: AppWindowPresentationKind) -> winsdk.system.Boolean: ...
    def request_presentation(self, presentation_kind: AppWindowPresentationKind) -> winsdk.system.Boolean: ...

class AppWindowTitleBar(winsdk.system.Object):
    inactive_foreground_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    inactive_background_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    foreground_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    extends_content_into_title_bar: winsdk.system.Boolean
    button_pressed_foreground_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    button_pressed_background_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    button_inactive_foreground_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    button_inactive_background_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    button_hover_foreground_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    button_hover_background_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    button_foreground_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    button_background_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    background_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    is_visible: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindowTitleBar: ...
    def get_preferred_visibility(self) -> AppWindowTitleBarVisibility: ...
    def get_title_bar_occlusions(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[AppWindowTitleBarOcclusion]]: ...
    def set_preferred_visibility(self, visibility_mode: AppWindowTitleBarVisibility) -> None: ...

class AppWindowTitleBarOcclusion(winsdk.system.Object):
    occluding_rect: winsdk.windows.foundation.Rect
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppWindowTitleBarOcclusion: ...

class CompactOverlayPresentationConfiguration(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CompactOverlayPresentationConfiguration: ...
    def __new__(cls: typing.Type[CompactOverlayPresentationConfiguration]) -> CompactOverlayPresentationConfiguration:...

class DefaultPresentationConfiguration(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DefaultPresentationConfiguration: ...
    def __new__(cls: typing.Type[DefaultPresentationConfiguration]) -> DefaultPresentationConfiguration:...

class DisplayRegion(winsdk.system.Object):
    display_monitor_device_id: str
    is_visible: winsdk.system.Boolean
    windowing_environment: typing.Optional[WindowingEnvironment]
    work_area_offset: winsdk.windows.foundation.Point
    work_area_size: winsdk.windows.foundation.Size
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DisplayRegion: ...
    def add_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[DisplayRegion, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class FullScreenPresentationConfiguration(winsdk.system.Object):
    is_exclusive: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FullScreenPresentationConfiguration: ...
    def __new__(cls: typing.Type[FullScreenPresentationConfiguration]) -> FullScreenPresentationConfiguration:...

class WindowServices(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowServices: ...
    @staticmethod
    def find_all_top_level_window_ids() -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.ui.WindowId]]: ...

class WindowingEnvironment(winsdk.system.Object):
    is_enabled: winsdk.system.Boolean
    kind: WindowingEnvironmentKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowingEnvironment: ...
    @typing.overload
    @staticmethod
    def find_all() -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[WindowingEnvironment]]: ...
    @typing.overload
    @staticmethod
    def find_all(kind: WindowingEnvironmentKind) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[WindowingEnvironment]]: ...
    def get_display_regions(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[DisplayRegion]]: ...
    def add_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[WindowingEnvironment, WindowingEnvironmentChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WindowingEnvironmentAddedEventArgs(winsdk.system.Object):
    windowing_environment: typing.Optional[WindowingEnvironment]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowingEnvironmentAddedEventArgs: ...

class WindowingEnvironmentChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowingEnvironmentChangedEventArgs: ...

class WindowingEnvironmentRemovedEventArgs(winsdk.system.Object):
    windowing_environment: typing.Optional[WindowingEnvironment]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WindowingEnvironmentRemovedEventArgs: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.networking.sockets
import winsdk.windows.security.credentials
import winsdk.windows.security.cryptography.certificates
import winsdk.windows.system
import winsdk.windows.web.http

class HttpCacheReadBehavior(enum.IntEnum):
    DEFAULT = 0
    MOST_RECENT = 1
    ONLY_FROM_CACHE = 2
    NO_CACHE = 3

class HttpCacheWriteBehavior(enum.IntEnum):
    DEFAULT = 0
    NO_CACHE = 1

class HttpCookieUsageBehavior(enum.IntEnum):
    DEFAULT = 0
    NO_COOKIES = 1

Self = typing.TypeVar('Self')

class HttpBaseProtocolFilter(winsdk.system.Object):
    use_proxy: winsdk.system.Boolean
    server_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    proxy_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    max_connections_per_server: winsdk.system.UInt32
    client_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    automatic_decompression: winsdk.system.Boolean
    allow_u_i: winsdk.system.Boolean
    allow_auto_redirect: winsdk.system.Boolean
    cache_control: typing.Optional[HttpCacheControl]
    cookie_manager: typing.Optional[winsdk.windows.web.http.HttpCookieManager]
    ignorable_server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    max_version: winsdk.windows.web.http.HttpVersion
    cookie_usage_behavior: HttpCookieUsageBehavior
    user: typing.Optional[winsdk.windows.system.User]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HttpBaseProtocolFilter: ...
    def __new__(cls: typing.Type[HttpBaseProtocolFilter]) -> HttpBaseProtocolFilter:...
    def clear_authentication_cache(self) -> None: ...
    def close(self) -> None: ...
    @staticmethod
    def create_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[HttpBaseProtocolFilter]: ...
    def send_request_async(self, request: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.web.http.HttpResponseMessage, winsdk.windows.web.http.HttpProgress]: ...
    def add_server_custom_validation_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[HttpBaseProtocolFilter, HttpServerCustomValidationRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_server_custom_validation_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class HttpCacheControl(winsdk.system.Object):
    write_behavior: HttpCacheWriteBehavior
    read_behavior: HttpCacheReadBehavior
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HttpCacheControl: ...

class HttpServerCustomValidationRequestedEventArgs(winsdk.system.Object):
    request_message: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]
    server_certificate: typing.Optional[winsdk.windows.security.cryptography.certificates.Certificate]
    server_certificate_error_severity: winsdk.windows.networking.sockets.SocketSslErrorSeverity
    server_certificate_errors: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.ChainValidationResult]]
    server_intermediate_certificates: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.cryptography.certificates.Certificate]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HttpServerCustomValidationRequestedEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...
    def reject(self) -> None: ...

class IHttpFilter(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IHttpFilter: ...
    def close(self) -> None: ...
    def send_request_async(self, request: typing.Optional[winsdk.windows.web.http.HttpRequestMessage]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.web.http.HttpResponseMessage, winsdk.windows.web.http.HttpProgress]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.system.power

Self = typing.TypeVar('Self')

class Battery(winsdk.system.Object):
    device_id: str
    aggregate_battery: typing.ClassVar[typing.Optional[Battery]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Battery: ...
    @staticmethod
    def from_id_async(device_id: str) -> winsdk.windows.foundation.IAsyncOperation[Battery]: ...
    @staticmethod
    def get_device_selector() -> str: ...
    def get_report(self) -> typing.Optional[BatteryReport]: ...
    def add_report_updated(self, handler: winsdk.windows.foundation.TypedEventHandler[Battery, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_report_updated(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class BatteryReport(winsdk.system.Object):
    charge_rate_in_milliwatts: typing.Optional[typing.Optional[winsdk.system.Int32]]
    design_capacity_in_milliwatt_hours: typing.Optional[typing.Optional[winsdk.system.Int32]]
    full_charge_capacity_in_milliwatt_hours: typing.Optional[typing.Optional[winsdk.system.Int32]]
    remaining_capacity_in_milliwatt_hours: typing.Optional[typing.Optional[winsdk.system.Int32]]
    status: winsdk.windows.system.power.BatteryStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BatteryReport: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class AutomationConnection(winsdk.system.Object):
    app_user_model_id: str
    executable_file_name: str
    is_remote_system: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AutomationConnection: ...

class AutomationConnectionBoundObject(winsdk.system.Object):
    connection: typing.Optional[AutomationConnection]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AutomationConnectionBoundObject: ...

class AutomationElement(winsdk.system.Object):
    app_user_model_id: str
    executable_file_name: str
    is_remote_system: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AutomationElement: ...

class AutomationTextRange(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AutomationTextRange: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Power")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.system.power
except ImportError:
    pass


Battery = _ns_module.Battery
BatteryReport = _ns_module.BatteryReport



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.networking.connectivity
import winsdk.windows.security.credentials

class WiFiAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

class WiFiConnectionMethod(enum.IntEnum):
    DEFAULT = 0
    WPS_PIN = 1
    WPS_PUSH_BUTTON = 2

class WiFiConnectionStatus(enum.IntEnum):
    UNSPECIFIED_FAILURE = 0
    SUCCESS = 1
    ACCESS_REVOKED = 2
    INVALID_CREDENTIAL = 3
    NETWORK_NOT_AVAILABLE = 4
    TIMEOUT = 5
    UNSUPPORTED_AUTHENTICATION_PROTOCOL = 6

class WiFiNetworkKind(enum.IntEnum):
    ANY = 0
    INFRASTRUCTURE = 1
    ADHOC = 2

class WiFiOnDemandHotspotAvailability(enum.IntEnum):
    AVAILABLE = 0
    UNAVAILABLE = 1

class WiFiOnDemandHotspotCellularBars(enum.IntEnum):
    ZERO_BARS = 0
    ONE_BAR = 1
    TWO_BARS = 2
    THREE_BARS = 3
    FOUR_BARS = 4
    FIVE_BARS = 5

class WiFiOnDemandHotspotConnectStatus(enum.IntEnum):
    UNSPECIFIED_FAILURE = 0
    SUCCESS = 1
    APP_TIMED_OUT = 2
    INVALID_CREDENTIAL = 3
    NETWORK_NOT_AVAILABLE = 4
    UNSUPPORTED_AUTHENTICATION_PROTOCOL = 5
    BLUETOOTH_CONNECT_FAILED = 6
    BLUETOOTH_TRANSMISSION_ERROR = 7
    OPERATION_CANCELED_BY_USER = 8
    ENTITLEMENT_CHECK_FAILED = 9
    NO_CELLULAR_SIGNAL = 10
    CELLULAR_DATA_TURNED_OFF = 11
    WLAN_CONNECT_FAILED = 12
    WLAN_NOT_VISIBLE = 13
    ACCESS_POINT_CANNOT_CONNECT = 14
    CELLULAR_CONNECT_TIMED_OUT = 15
    ROAMING_NOT_ALLOWED = 16
    PAIRING_REQUIRED = 17
    DATA_LIMIT_REACHED = 18

class WiFiPhyKind(enum.IntEnum):
    UNKNOWN = 0
    FHSS = 1
    DSSS = 2
    I_R_BASEBAND = 3
    OFDM = 4
    HRDSSS = 5
    ERP = 6
    H_T = 7
    VHT = 8
    DMG = 9
    H_E = 10
    EHT = 11

class WiFiReconnectionKind(enum.IntEnum):
    AUTOMATIC = 0
    MANUAL = 1

class WiFiWpsConfigurationStatus(enum.IntEnum):
    UNSPECIFIED_FAILURE = 0
    SUCCESS = 1
    TIMEOUT = 2

class WiFiWpsKind(enum.IntEnum):
    UNKNOWN = 0
    PIN = 1
    PUSH_BUTTON = 2
    NFC = 3
    ETHERNET = 4
    USB = 5

Self = typing.TypeVar('Self')

class WiFiAdapter(winsdk.system.Object):
    network_adapter: typing.Optional[winsdk.windows.networking.connectivity.NetworkAdapter]
    network_report: typing.Optional[WiFiNetworkReport]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WiFiAdapter: ...
    @typing.overload
    def connect_async(self, available_network: typing.Optional[WiFiAvailableNetwork], reconnection_kind: WiFiReconnectionKind) -> winsdk.windows.foundation.IAsyncOperation[WiFiConnectionResult]: ...
    @typing.overload
    def connect_async(self, available_network: typing.Optional[WiFiAvailableNetwork], reconnection_kind: WiFiReconnectionKind, password_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]) -> winsdk.windows.foundation.IAsyncOperation[WiFiConnectionResult]: ...
    @typing.overload
    def connect_async(self, available_network: typing.Optional[WiFiAvailableNetwork], reconnection_kind: WiFiReconnectionKind, password_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential], ssid: str) -> winsdk.windows.foundation.IAsyncOperation[WiFiConnectionResult]: ...
    @typing.overload
    def connect_async(self, available_network: typing.Optional[WiFiAvailableNetwork], reconnection_kind: WiFiReconnectionKind, password_credential: typing.Optional[winsdk.windows.security.credentials.PasswordCredential], ssid: str, connection_method: WiFiConnectionMethod) -> winsdk.windows.foundation.IAsyncOperation[WiFiConnectionResult]: ...
    def disconnect(self) -> None: ...
    @staticmethod
    def find_all_adapters_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[WiFiAdapter]]: ...
    @staticmethod
    def from_id_async(device_id: str) -> winsdk.windows.foundation.IAsyncOperation[WiFiAdapter]: ...
    @staticmethod
    def get_device_selector() -> str: ...
    def get_wps_configuration_async(self, available_network: typing.Optional[WiFiAvailableNetwork]) -> winsdk.windows.foundation.IAsyncOperation[WiFiWpsConfigurationResult]: ...
    @staticmethod
    def request_access_async() -> winsdk.windows.foundation.IAsyncOperation[WiFiAccessStatus]: ...
    def scan_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_available_networks_changed(self, args: winsdk.windows.foundation.TypedEventHandler[WiFiAdapter, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_available_networks_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class WiFiAvailableNetwork(winsdk.system.Object):
    beacon_interval: datetime.timedelta
    bssid: str
    channel_center_frequency_in_kilohertz: winsdk.system.Int32
    is_wi_fi_direct: winsdk.system.Boolean
    network_kind: WiFiNetworkKind
    network_rssi_in_decibel_milliwatts: winsdk.system.Double
    phy_kind: WiFiPhyKind
    security_settings: typing.Optional[winsdk.windows.networking.connectivity.NetworkSecuritySettings]
    signal_bars: winsdk.system.UInt8
    ssid: str
    uptime: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WiFiAvailableNetwork: ...

class WiFiConnectionResult(winsdk.system.Object):
    connection_status: WiFiConnectionStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WiFiConnectionResult: ...

class WiFiNetworkReport(winsdk.system.Object):
    available_networks: typing.Optional[winsdk.windows.foundation.collections.IVectorView[WiFiAvailableNetwork]]
    timestamp: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WiFiNetworkReport: ...

class WiFiOnDemandHotspotConnectTriggerDetails(winsdk.system.Object):
    requested_network: typing.Optional[WiFiOnDemandHotspotNetwork]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WiFiOnDemandHotspotConnectTriggerDetails: ...
    def connect(self) -> typing.Optional[WiFiOnDemandHotspotConnectionResult]: ...
    def connect_async(self) -> winsdk.windows.foundation.IAsyncOperation[WiFiOnDemandHotspotConnectionResult]: ...
    def report_error(self, status: WiFiOnDemandHotspotConnectStatus) -> None: ...

class WiFiOnDemandHotspotConnectionResult(winsdk.system.Object):
    status: WiFiOnDemandHotspotConnectStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WiFiOnDemandHotspotConnectionResult: ...

class WiFiOnDemandHotspotNetwork(winsdk.system.Object):
    id: winsdk.system.Guid
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WiFiOnDemandHotspotNetwork: ...
    @staticmethod
    def get_or_create_by_id(network_id: winsdk.system.Guid) -> typing.Optional[WiFiOnDemandHotspotNetwork]: ...
    def get_properties(self) -> typing.Optional[WiFiOnDemandHotspotNetworkProperties]: ...
    def update_properties(self, new_properties: typing.Optional[WiFiOnDemandHotspotNetworkProperties]) -> None: ...

class WiFiOnDemandHotspotNetworkProperties(winsdk.system.Object):
    ssid: str
    remaining_battery_percent: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    password: typing.Optional[winsdk.windows.security.credentials.PasswordCredential]
    is_metered: winsdk.system.Boolean
    display_name: str
    cellular_bars: typing.Optional[typing.Optional[WiFiOnDemandHotspotCellularBars]]
    availability: WiFiOnDemandHotspotAvailability
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WiFiOnDemandHotspotNetworkProperties: ...

class WiFiWpsConfigurationResult(winsdk.system.Object):
    status: WiFiWpsConfigurationStatus
    supported_wps_kinds: typing.Optional[winsdk.windows.foundation.collections.IVectorView[WiFiWpsKind]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WiFiWpsConfigurationResult: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Lights")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class LampArrayKind(enum.IntEnum):
    UNDEFINED = 0
    KEYBOARD = 1
    MOUSE = 2
    GAME_CONTROLLER = 3
    PERIPHERAL = 4
    SCENE = 5
    NOTIFICATION = 6
    CHASSIS = 7
    WEARABLE = 8
    FURNITURE = 9
    ART = 10

class LampPurposes(enum.IntFlag):
    UNDEFINED = 0
    CONTROL = 0x1
    ACCENT = 0x2
    BRANDING = 0x4
    STATUS = 0x8
    ILLUMINATION = 0x10
    PRESENTATION = 0x20

_ns_module._register_LampArrayKind(LampArrayKind)
_ns_module._register_LampPurposes(LampPurposes)

Lamp = _ns_module.Lamp
LampArray = _ns_module.LampArray
LampAvailabilityChangedEventArgs = _ns_module.LampAvailabilityChangedEventArgs
LampInfo = _ns_module.LampInfo



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Services.Maps")

try:
    import winsdk.windows.devices.geolocation
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.ui.popups
except ImportError:
    pass

class ManeuverWarningKind(enum.IntEnum):
    NONE = 0
    ACCIDENT = 1
    ADMINISTRATIVE_DIVISION_CHANGE = 2
    ALERT = 3
    BLOCKED_ROAD = 4
    CHECK_TIMETABLE = 5
    CONGESTION = 6
    CONSTRUCTION = 7
    COUNTRY_CHANGE = 8
    DISABLED_VEHICLE = 9
    GATE_ACCESS = 10
    GET_OFF_TRANSIT = 11
    GET_ON_TRANSIT = 12
    ILLEGAL_U_TURN = 13
    MASS_TRANSIT = 14
    MISCELLANEOUS = 15
    NO_INCIDENT = 16
    OTHER = 17
    OTHER_NEWS = 18
    OTHER_TRAFFIC_INCIDENTS = 19
    PLANNED_EVENT = 20
    PRIVATE_ROAD = 21
    RESTRICTED_TURN = 22
    ROAD_CLOSURES = 23
    ROAD_HAZARD = 24
    SCHEDULED_CONSTRUCTION = 25
    SEASONAL_CLOSURES = 26
    TOLLBOOTH = 27
    TOLL_ROAD = 28
    TOLL_ZONE_ENTER = 29
    TOLL_ZONE_EXIT = 30
    TRAFFIC_FLOW = 31
    TRANSIT_LINE_CHANGE = 32
    UNPAVED_ROAD = 33
    UNSCHEDULED_CONSTRUCTION = 34
    WEATHER = 35

class ManeuverWarningSeverity(enum.IntEnum):
    NONE = 0
    LOW_IMPACT = 1
    MINOR = 2
    MODERATE = 3
    SERIOUS = 4

class MapLocationDesiredAccuracy(enum.IntEnum):
    HIGH = 0
    LOW = 1

class MapLocationFinderStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    INVALID_CREDENTIALS = 2
    BAD_LOCATION = 3
    INDEX_FAILURE = 4
    NETWORK_FAILURE = 5
    NOT_SUPPORTED = 6

class MapManeuverNotices(enum.IntFlag):
    NONE = 0
    TOLL = 0x1
    UNPAVED = 0x2

class MapRouteFinderStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    INVALID_CREDENTIALS = 2
    NO_ROUTE_FOUND = 3
    NO_ROUTE_FOUND_WITH_GIVEN_OPTIONS = 4
    START_POINT_NOT_FOUND = 5
    END_POINT_NOT_FOUND = 6
    NO_PEDESTRIAN_ROUTE_FOUND = 7
    NETWORK_FAILURE = 8
    NOT_SUPPORTED = 9

class MapRouteManeuverKind(enum.IntEnum):
    NONE = 0
    START = 1
    STOPOVER = 2
    STOPOVER_RESUME = 3
    END = 4
    GO_STRAIGHT = 5
    U_TURN_LEFT = 6
    U_TURN_RIGHT = 7
    TURN_KEEP_LEFT = 8
    TURN_KEEP_RIGHT = 9
    TURN_LIGHT_LEFT = 10
    TURN_LIGHT_RIGHT = 11
    TURN_LEFT = 12
    TURN_RIGHT = 13
    TURN_HARD_LEFT = 14
    TURN_HARD_RIGHT = 15
    FREEWAY_ENTER_LEFT = 16
    FREEWAY_ENTER_RIGHT = 17
    FREEWAY_LEAVE_LEFT = 18
    FREEWAY_LEAVE_RIGHT = 19
    FREEWAY_CONTINUE_LEFT = 20
    FREEWAY_CONTINUE_RIGHT = 21
    TRAFFIC_CIRCLE_LEFT = 22
    TRAFFIC_CIRCLE_RIGHT = 23
    TAKE_FERRY = 24

class MapRouteOptimization(enum.IntEnum):
    TIME = 0
    DISTANCE = 1
    TIME_WITH_TRAFFIC = 2
    SCENIC = 3

class MapRouteRestrictions(enum.IntFlag):
    NONE = 0
    HIGHWAYS = 0x1
    TOLL_ROADS = 0x2
    FERRIES = 0x4
    TUNNELS = 0x8
    DIRT_ROADS = 0x10
    MOTORAIL = 0x20

class MapServiceDataUsagePreference(enum.IntEnum):
    DEFAULT = 0
    OFFLINE_MAP_DATA_ONLY = 1

class TrafficCongestion(enum.IntEnum):
    UNKNOWN = 0
    LIGHT = 1
    MILD = 2
    MEDIUM = 3
    HEAVY = 4

class WaypointKind(enum.IntEnum):
    STOP = 0
    VIA = 1

_ns_module._register_ManeuverWarningKind(ManeuverWarningKind)
_ns_module._register_ManeuverWarningSeverity(ManeuverWarningSeverity)
_ns_module._register_MapLocationDesiredAccuracy(MapLocationDesiredAccuracy)
_ns_module._register_MapLocationFinderStatus(MapLocationFinderStatus)
_ns_module._register_MapManeuverNotices(MapManeuverNotices)
_ns_module._register_MapRouteFinderStatus(MapRouteFinderStatus)
_ns_module._register_MapRouteManeuverKind(MapRouteManeuverKind)
_ns_module._register_MapRouteOptimization(MapRouteOptimization)
_ns_module._register_MapRouteRestrictions(MapRouteRestrictions)
_ns_module._register_MapServiceDataUsagePreference(MapServiceDataUsagePreference)
_ns_module._register_TrafficCongestion(TrafficCongestion)
_ns_module._register_WaypointKind(WaypointKind)

EnhancedWaypoint = _ns_module.EnhancedWaypoint
ManeuverWarning = _ns_module.ManeuverWarning
MapAddress = _ns_module.MapAddress
MapLocation = _ns_module.MapLocation
MapLocationFinder = _ns_module.MapLocationFinder
MapLocationFinderResult = _ns_module.MapLocationFinderResult
MapManager = _ns_module.MapManager
MapRoute = _ns_module.MapRoute
MapRouteDrivingOptions = _ns_module.MapRouteDrivingOptions
MapRouteFinder = _ns_module.MapRouteFinder
MapRouteFinderResult = _ns_module.MapRouteFinderResult
MapRouteLeg = _ns_module.MapRouteLeg
MapRouteManeuver = _ns_module.MapRouteManeuver
MapService = _ns_module.MapService
PlaceInfo = _ns_module.PlaceInfo
PlaceInfoCreateOptions = _ns_module.PlaceInfoCreateOptions



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Geolocation.Provider")

try:
    import winsdk.windows.devices.geolocation
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

class LocationOverrideStatus(enum.IntEnum):
    SUCCESS = 0
    ACCESS_DENIED = 1
    ALREADY_STARTED = 2
    OTHER = 3

_ns_module._register_LocationOverrideStatus(LocationOverrideStatus)

GeolocationProvider = _ns_module.GeolocationProvider



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Input.Inking.Core")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.ui.composition
except ImportError:
    pass

try:
    import winsdk.windows.ui.core
except ImportError:
    pass

try:
    import winsdk.windows.ui.input.inking
except ImportError:
    pass

class CoreWetStrokeDisposition(enum.IntEnum):
    INKING = 0
    COMPLETED = 1
    CANCELED = 2

_ns_module._register_CoreWetStrokeDisposition(CoreWetStrokeDisposition)

CoreIncrementalInkStroke = _ns_module.CoreIncrementalInkStroke
CoreInkIndependentInputSource = _ns_module.CoreInkIndependentInputSource
CoreInkPresenterHost = _ns_module.CoreInkPresenterHost
CoreWetStrokeUpdateEventArgs = _ns_module.CoreWetStrokeUpdateEventArgs
CoreWetStrokeUpdateSource = _ns_module.CoreWetStrokeUpdateSource



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

class ExtendedExecutionForegroundReason(enum.IntEnum):
    UNSPECIFIED = 0
    SAVING_DATA = 1
    BACKGROUND_AUDIO = 2
    UNCONSTRAINED = 3

class ExtendedExecutionForegroundResult(enum.IntEnum):
    ALLOWED = 0
    DENIED = 1

class ExtendedExecutionForegroundRevokedReason(enum.IntEnum):
    RESUMED = 0
    SYSTEM_POLICY = 1

Self = typing.TypeVar('Self')

class ExtendedExecutionForegroundRevokedEventArgs(winsdk.system.Object):
    reason: ExtendedExecutionForegroundRevokedReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ExtendedExecutionForegroundRevokedEventArgs: ...

class ExtendedExecutionForegroundSession(winsdk.system.Object):
    reason: ExtendedExecutionForegroundReason
    description: str
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ExtendedExecutionForegroundSession: ...
    def __new__(cls: typing.Type[ExtendedExecutionForegroundSession]) -> ExtendedExecutionForegroundSession:...
    def close(self) -> None: ...
    def request_extension_async(self) -> winsdk.windows.foundation.IAsyncOperation[ExtendedExecutionForegroundResult]: ...
    def add_revoked(self, handler: winsdk.windows.foundation.TypedEventHandler[winsdk.system.Object, ExtendedExecutionForegroundRevokedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_revoked(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Web.Syndication")

try:
    import winsdk.windows.data.xml.dom
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.credentials
except ImportError:
    pass

class SyndicationErrorStatus(enum.IntEnum):
    UNKNOWN = 0
    MISSING_REQUIRED_ELEMENT = 1
    MISSING_REQUIRED_ATTRIBUTE = 2
    INVALID_XML = 3
    UNEXPECTED_CONTENT = 4
    UNSUPPORTED_FORMAT = 5

class SyndicationFormat(enum.IntEnum):
    ATOM10 = 0
    RSS20 = 1
    RSS10 = 2
    RSS092 = 3
    RSS091 = 4
    ATOM03 = 5

class SyndicationTextType(enum.IntEnum):
    TEXT = 0
    HTML = 1
    XHTML = 2

_ns_module._register_SyndicationErrorStatus(SyndicationErrorStatus)
_ns_module._register_SyndicationFormat(SyndicationFormat)
_ns_module._register_SyndicationTextType(SyndicationTextType)

RetrievalProgress = _ns_module.RetrievalProgress
TransferProgress = _ns_module.TransferProgress
SyndicationAttribute = _ns_module.SyndicationAttribute
SyndicationCategory = _ns_module.SyndicationCategory
SyndicationClient = _ns_module.SyndicationClient
SyndicationContent = _ns_module.SyndicationContent
SyndicationError = _ns_module.SyndicationError
SyndicationFeed = _ns_module.SyndicationFeed
SyndicationGenerator = _ns_module.SyndicationGenerator
SyndicationItem = _ns_module.SyndicationItem
SyndicationLink = _ns_module.SyndicationLink
SyndicationNode = _ns_module.SyndicationNode
SyndicationPerson = _ns_module.SyndicationPerson
SyndicationText = _ns_module.SyndicationText
ISyndicationClient = _ns_module.ISyndicationClient
ISyndicationNode = _ns_module.ISyndicationNode
ISyndicationText = _ns_module.ISyndicationText



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.contacts
import winsdk.windows.foundation

Self = typing.TypeVar('Self')

class ContactDataProviderConnection(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactDataProviderConnection: ...
    def start(self) -> None: ...
    def add_server_search_read_batch_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[ContactDataProviderConnection, ContactListServerSearchReadBatchRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_server_search_read_batch_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_sync_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[ContactDataProviderConnection, ContactListSyncManagerSyncRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sync_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_create_or_update_contact_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[ContactDataProviderConnection, ContactListCreateOrUpdateContactRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_create_or_update_contact_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_delete_contact_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[ContactDataProviderConnection, ContactListDeleteContactRequestEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_delete_contact_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ContactDataProviderTriggerDetails(winsdk.system.Object):
    connection: typing.Optional[ContactDataProviderConnection]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactDataProviderTriggerDetails: ...

class ContactListCreateOrUpdateContactRequest(winsdk.system.Object):
    contact: typing.Optional[winsdk.windows.applicationmodel.contacts.Contact]
    contact_list_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListCreateOrUpdateContactRequest: ...
    def report_completed_async(self, created_or_updated_contact: typing.Optional[winsdk.windows.applicationmodel.contacts.Contact]) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class ContactListCreateOrUpdateContactRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[ContactListCreateOrUpdateContactRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListCreateOrUpdateContactRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class ContactListDeleteContactRequest(winsdk.system.Object):
    contact_id: str
    contact_list_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListDeleteContactRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class ContactListDeleteContactRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[ContactListDeleteContactRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListDeleteContactRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class ContactListServerSearchReadBatchRequest(winsdk.system.Object):
    contact_list_id: str
    options: typing.Optional[winsdk.windows.applicationmodel.contacts.ContactQueryOptions]
    session_id: str
    suggested_batch_size: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListServerSearchReadBatchRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_failed_async(self, batch_status: winsdk.windows.applicationmodel.contacts.ContactBatchStatus) -> winsdk.windows.foundation.IAsyncAction: ...
    def save_contact_async(self, contact: typing.Optional[winsdk.windows.applicationmodel.contacts.Contact]) -> winsdk.windows.foundation.IAsyncAction: ...

class ContactListServerSearchReadBatchRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[ContactListServerSearchReadBatchRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListServerSearchReadBatchRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class ContactListSyncManagerSyncRequest(winsdk.system.Object):
    contact_list_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListSyncManagerSyncRequest: ...
    def report_completed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def report_failed_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class ContactListSyncManagerSyncRequestEventArgs(winsdk.system.Object):
    request: typing.Optional[ContactListSyncManagerSyncRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListSyncManagerSyncRequestEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class IGraphicsEffect(winsdk.system.Object):
    name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IGraphicsEffect: ...

class IGraphicsEffectSource(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IGraphicsEffectSource: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.ui.text.core

class AlternateNormalizationFormat(enum.IntEnum):
    NOT_NORMALIZED = 0
    NUMBER = 1
    CURRENCY = 3
    DATE = 4
    TIME = 5

class TextPredictionOptions(enum.IntFlag):
    NONE = 0
    PREDICTIONS = 0x1
    CORRECTIONS = 0x2

class UnicodeGeneralCategory(enum.IntEnum):
    UPPERCASE_LETTER = 0
    LOWERCASE_LETTER = 1
    TITLECASE_LETTER = 2
    MODIFIER_LETTER = 3
    OTHER_LETTER = 4
    NONSPACING_MARK = 5
    SPACING_COMBINING_MARK = 6
    ENCLOSING_MARK = 7
    DECIMAL_DIGIT_NUMBER = 8
    LETTER_NUMBER = 9
    OTHER_NUMBER = 10
    SPACE_SEPARATOR = 11
    LINE_SEPARATOR = 12
    PARAGRAPH_SEPARATOR = 13
    CONTROL = 14
    FORMAT = 15
    SURROGATE = 16
    PRIVATE_USE = 17
    CONNECTOR_PUNCTUATION = 18
    DASH_PUNCTUATION = 19
    OPEN_PUNCTUATION = 20
    CLOSE_PUNCTUATION = 21
    INITIAL_QUOTE_PUNCTUATION = 22
    FINAL_QUOTE_PUNCTUATION = 23
    OTHER_PUNCTUATION = 24
    MATH_SYMBOL = 25
    CURRENCY_SYMBOL = 26
    MODIFIER_SYMBOL = 27
    OTHER_SYMBOL = 28
    NOT_ASSIGNED = 29

class UnicodeNumericType(enum.IntEnum):
    NONE = 0
    DECIMAL = 1
    DIGIT = 2
    NUMERIC = 3

Self = typing.TypeVar('Self')

class TextSegment:
    start_position: winsdk.system.UInt32
    length: winsdk.system.UInt32
    def __new__(cls: typing.Type[TextSegment], start_position: winsdk.system.UInt32, length: winsdk.system.UInt32) -> TextSegment: ...

class AlternateWordForm(winsdk.system.Object):
    alternate_text: str
    normalization_format: AlternateNormalizationFormat
    source_text_segment: TextSegment
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AlternateWordForm: ...

class SelectableWordSegment(winsdk.system.Object):
    source_text_segment: TextSegment
    text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SelectableWordSegment: ...

class SelectableWordsSegmenter(winsdk.system.Object):
    resolved_language: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SelectableWordsSegmenter: ...
    def __new__(cls: typing.Type[SelectableWordsSegmenter], language: str) -> SelectableWordsSegmenter:...
    def get_token_at(self, text: str, start_index: winsdk.system.UInt32) -> typing.Optional[SelectableWordSegment]: ...
    def get_tokens(self, text: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[SelectableWordSegment]]: ...
    def tokenize(self, text: str, start_index: winsdk.system.UInt32, handler: typing.Optional[SelectableWordSegmentsTokenizingHandler]) -> None: ...

class SemanticTextQuery(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SemanticTextQuery: ...
    @typing.overload
    def __new__(cls: typing.Type[SemanticTextQuery], aqs_filter: str) -> SemanticTextQuery:...
    @typing.overload
    def __new__(cls: typing.Type[SemanticTextQuery], aqs_filter: str, filter_language: str) -> SemanticTextQuery:...
    def find(self, content: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[TextSegment]]: ...
    def find_in_property(self, property_content: str, property_name: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[TextSegment]]: ...

class TextConversionGenerator(winsdk.system.Object):
    language_available_but_not_installed: winsdk.system.Boolean
    resolved_language: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TextConversionGenerator: ...
    def __new__(cls: typing.Type[TextConversionGenerator], language_tag: str) -> TextConversionGenerator:...
    @typing.overload
    def get_candidates_async(self, input: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[str]]: ...
    @typing.overload
    def get_candidates_async(self, input: str, max_candidates: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[str]]: ...

class TextPhoneme(winsdk.system.Object):
    display_text: str
    reading_text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TextPhoneme: ...

class TextPredictionGenerator(winsdk.system.Object):
    language_available_but_not_installed: winsdk.system.Boolean
    resolved_language: str
    input_scope: winsdk.windows.ui.text.core.CoreTextInputScope
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TextPredictionGenerator: ...
    def __new__(cls: typing.Type[TextPredictionGenerator], language_tag: str) -> TextPredictionGenerator:...
    @typing.overload
    def get_candidates_async(self, input: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[str]]: ...
    @typing.overload
    def get_candidates_async(self, input: str, max_candidates: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[str]]: ...
    @typing.overload
    def get_candidates_async(self, input: str, max_candidates: winsdk.system.UInt32, prediction_options: TextPredictionOptions, previous_strings: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[str]]: ...
    def get_next_word_candidates_async(self, max_candidates: winsdk.system.UInt32, previous_strings: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[str]]: ...

class TextReverseConversionGenerator(winsdk.system.Object):
    language_available_but_not_installed: winsdk.system.Boolean
    resolved_language: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TextReverseConversionGenerator: ...
    def __new__(cls: typing.Type[TextReverseConversionGenerator], language_tag: str) -> TextReverseConversionGenerator:...
    def convert_back_async(self, input: str) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    def get_phonemes_async(self, input: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[TextPhoneme]]: ...

class UnicodeCharacters(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UnicodeCharacters: ...
    @staticmethod
    def get_codepoint_from_surrogate_pair(high_surrogate: winsdk.system.UInt32, low_surrogate: winsdk.system.UInt32) -> winsdk.system.UInt32: ...
    @staticmethod
    def get_general_category(codepoint: winsdk.system.UInt32) -> UnicodeGeneralCategory: ...
    @staticmethod
    def get_numeric_type(codepoint: winsdk.system.UInt32) -> UnicodeNumericType: ...
    @staticmethod
    def get_surrogate_pair_from_codepoint(codepoint: winsdk.system.UInt32) -> typing.Tuple[winsdk.system.Char16, winsdk.system.Char16]: ...
    @staticmethod
    def is_alphabetic(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_cased(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_grapheme_base(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_grapheme_extend(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_high_surrogate(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_id_continue(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_id_start(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_low_surrogate(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_lowercase(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_noncharacter(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_supplementary(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_uppercase(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_whitespace(codepoint: winsdk.system.UInt32) -> winsdk.system.Boolean: ...

class WordSegment(winsdk.system.Object):
    alternate_forms: typing.Optional[winsdk.windows.foundation.collections.IVectorView[AlternateWordForm]]
    source_text_segment: TextSegment
    text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WordSegment: ...

class WordsSegmenter(winsdk.system.Object):
    resolved_language: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WordsSegmenter: ...
    def __new__(cls: typing.Type[WordsSegmenter], language: str) -> WordsSegmenter:...
    def get_token_at(self, text: str, start_index: winsdk.system.UInt32) -> typing.Optional[WordSegment]: ...
    def get_tokens(self, text: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[WordSegment]]: ...
    def tokenize(self, text: str, start_index: winsdk.system.UInt32, handler: typing.Optional[WordSegmentsTokenizingHandler]) -> None: ...

SelectableWordSegmentsTokenizingHandler = typing.Callable[[typing.Iterable[SelectableWordSegment], typing.Iterable[SelectableWordSegment]], None]

WordSegmentsTokenizingHandler = typing.Callable[[typing.Iterable[WordSegment], typing.Iterable[WordSegment]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Graphics.Holographic")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx.direct3d11
except ImportError:
    pass

try:
    import winsdk.windows.perception
except ImportError:
    pass

try:
    import winsdk.windows.perception.spatial
except ImportError:
    pass

try:
    import winsdk.windows.ui.core
except ImportError:
    pass

class HolographicDepthReprojectionMethod(enum.IntEnum):
    DEPTH_REPROJECTION = 0
    AUTO_PLANAR = 1

class HolographicFramePresentResult(enum.IntEnum):
    SUCCESS = 0
    DEVICE_REMOVED = 1

class HolographicFramePresentWaitBehavior(enum.IntEnum):
    WAIT_FOR_FRAME_TO_FINISH = 0
    DO_NOT_WAIT_FOR_FRAME_TO_FINISH = 1

class HolographicReprojectionMode(enum.IntEnum):
    POSITION_AND_ORIENTATION = 0
    ORIENTATION_ONLY = 1
    DISABLED = 2

class HolographicSpaceUserPresence(enum.IntEnum):
    ABSENT = 0
    PRESENT_PASSIVE = 1
    PRESENT_ACTIVE = 2

class HolographicViewConfigurationKind(enum.IntEnum):
    DISPLAY = 0
    PHOTO_VIDEO_CAMERA = 1

_ns_module._register_HolographicDepthReprojectionMethod(HolographicDepthReprojectionMethod)
_ns_module._register_HolographicFramePresentResult(HolographicFramePresentResult)
_ns_module._register_HolographicFramePresentWaitBehavior(HolographicFramePresentWaitBehavior)
_ns_module._register_HolographicReprojectionMode(HolographicReprojectionMode)
_ns_module._register_HolographicSpaceUserPresence(HolographicSpaceUserPresence)
_ns_module._register_HolographicViewConfigurationKind(HolographicViewConfigurationKind)

HolographicAdapterId = _ns_module.HolographicAdapterId
HolographicFrameId = _ns_module.HolographicFrameId
HolographicStereoTransform = _ns_module.HolographicStereoTransform
HolographicCamera = _ns_module.HolographicCamera
HolographicCameraPose = _ns_module.HolographicCameraPose
HolographicCameraRenderingParameters = _ns_module.HolographicCameraRenderingParameters
HolographicCameraViewportParameters = _ns_module.HolographicCameraViewportParameters
HolographicDisplay = _ns_module.HolographicDisplay
HolographicFrame = _ns_module.HolographicFrame
HolographicFramePrediction = _ns_module.HolographicFramePrediction
HolographicFramePresentationMonitor = _ns_module.HolographicFramePresentationMonitor
HolographicFramePresentationReport = _ns_module.HolographicFramePresentationReport
HolographicFrameRenderingReport = _ns_module.HolographicFrameRenderingReport
HolographicFrameScanoutMonitor = _ns_module.HolographicFrameScanoutMonitor
HolographicFrameScanoutReport = _ns_module.HolographicFrameScanoutReport
HolographicQuadLayer = _ns_module.HolographicQuadLayer
HolographicQuadLayerUpdateParameters = _ns_module.HolographicQuadLayerUpdateParameters
HolographicSpace = _ns_module.HolographicSpace
HolographicSpaceCameraAddedEventArgs = _ns_module.HolographicSpaceCameraAddedEventArgs
HolographicSpaceCameraRemovedEventArgs = _ns_module.HolographicSpaceCameraRemovedEventArgs
HolographicViewConfiguration = _ns_module.HolographicViewConfiguration



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.UserDataAccounts")

try:
    import winsdk.windows.applicationmodel.appointments
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.email
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.userdatatasks
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class UserDataAccountContentKinds(enum.IntFlag):
    EMAIL = 0x1
    CONTACT = 0x2
    APPOINTMENT = 0x4

class UserDataAccountOtherAppReadAccess(enum.IntEnum):
    SYSTEM_ONLY = 0
    FULL = 1
    NONE = 2

class UserDataAccountStoreAccessType(enum.IntEnum):
    ALL_ACCOUNTS_READ_ONLY = 0
    APP_ACCOUNTS_READ_WRITE = 1

_ns_module._register_UserDataAccountContentKinds(UserDataAccountContentKinds)
_ns_module._register_UserDataAccountOtherAppReadAccess(UserDataAccountOtherAppReadAccess)
_ns_module._register_UserDataAccountStoreAccessType(UserDataAccountStoreAccessType)

UserDataAccount = _ns_module.UserDataAccount
UserDataAccountManager = _ns_module.UserDataAccountManager
UserDataAccountManagerForUser = _ns_module.UserDataAccountManagerForUser
UserDataAccountStore = _ns_module.UserDataAccountStore
UserDataAccountStoreChangedEventArgs = _ns_module.UserDataAccountStoreChangedEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.ui.notifications

class UserNotificationListenerAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED = 2

Self = typing.TypeVar('Self')

class UserNotificationListener(winsdk.system.Object):
    current: typing.ClassVar[typing.Optional[UserNotificationListener]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserNotificationListener: ...
    def clear_notifications(self) -> None: ...
    def get_access_status(self) -> UserNotificationListenerAccessStatus: ...
    def get_notification(self, notification_id: winsdk.system.UInt32) -> typing.Optional[winsdk.windows.ui.notifications.UserNotification]: ...
    def get_notifications_async(self, kinds: winsdk.windows.ui.notifications.NotificationKinds) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.ui.notifications.UserNotification]]: ...
    def remove_notification(self, notification_id: winsdk.system.UInt32) -> None: ...
    def request_access_async(self) -> winsdk.windows.foundation.IAsyncOperation[UserNotificationListenerAccessStatus]: ...
    def add_notification_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[UserNotificationListener, winsdk.windows.ui.notifications.UserNotificationChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_notification_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

